import React, { Component } from "react";
import ReactAplayer from "react-aplayer";
import Header from "./Header";
import RankingList from "./RankingList";
import FavoriteList from "./FavoriteList";
import tracks from "./datas";
import "./App.css";
import "./fonts/BebasNeue/BebasNeue-Regular.ttf";

export default class App extends Component {
  constructor(props) {
    super(props);
    this.state = {
      tracks: tracks,
    };
  }

  
  onInit = (ap) => {
    this.ap = ap;
  };

  // tips，處理加入或移除我的最愛功能
  handleToggleFavorite = (id) => {
    this.setState((preState) => {
      return {
        tracks: preState.tracks.map((track) => {
          if (track.id === id) {
            if (track.favorite) {
              return {
                ...track,
                favorite: false,
              };
            } else {
              return {
                ...track,
                favorite: true,
              };
            }
          }
          return track;
        }),
      };
    });
  };

  // tips，處理移除我的最愛功能
  handleRemoveFavorite = (id) => {
    console.log(id);
    this.setState((preState) => {
      return {
        tracks: preState.tracks.map((track) => {
          return track.id === id ? { ...track, favorite: false } : track;
        }),
      };
    });
  };

  // tips，處理增加 like 計數功能
  handleIncreaseLikeCount = (id) => {
    this.setState((preState) => {
      return {
        tracks: preState.tracks.map((track) => {
          return id === track.id
            ? { ...track, likeCount: track.likeCount + 1 }
            : track;
        }),
      };
    });
  };

  // tips，處理減少 like 計數功能
  handleDecreaseLikeCount = (id) => {
    this.setState((preState) => {
      return {
        tracks: preState.tracks.map((track) => {
          return id === track.id && track.likeCount > 0
            ? { ...track, likeCount: track.likeCount - 1 }
            : track;
        }),
      };
    });
  };

  render() {
    return (
      <div className="app">
        <Header info="Cll0156107 劉育呈" />
        <div className="main">
          {/* tips，傳入歌曲資料及相關事件的傳遞 */}
          <RankingList
            list={this.state.tracks}
            onIncreseLike={this.handleIncreaseLikeCount}
            onDecreaseLike={this.handleDecreaseLikeCount}
            onFavorite={this.handleToggleFavorite}
          />
          {/* tips，傳入歌曲資料及相關事件的傳遞 */}
          <FavoriteList
            list={this.state.tracks}
            onDeleteFavorite={this.handleRemoveFavorite}
          />
        </div>
      </div>
    );
  }
}
