import React from "react";
import FavoriteListItem from "./FavoriteListItem";
import { transferTimeToHumanize } from "./utils";

// tips: 計算歌曲總長度時間可善用 array.reduce() 方法進行加總
const FavoriteList = (props) => {
  const favoriteList = props.list.filter((track) => track.favorite === true);

  const time = favoriteList.reduce(
    (t, musicTime) => t + musicTime.musicTime,
    0
  );
  return (
    <div className="favorite-list list">
      <div className="title">
        我的最愛
        {/* tips: 善用 utils.js 的 transferTimeToHumanize 方法轉換歌曲時間的顯示格式 */}
        <span className="total">{transferTimeToHumanize(time)}</span>
      </div>
      {/* tips，傳入歌曲資料與適當的 callback */}
      {favoriteList.map((track) =>
        track.favorite ? (
          <FavoriteListItem
            track={track}
            key={track.id}
            id={track.id}
            onRemoveFavorite={props.onDeleteFavorite}
          />
        ) : null
      )}
    </div>
  );
};

export default FavoriteList;
